(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6073,        201]*)
(*NotebookOutlinePosition[      6719,        223]*)
(*  CellTagsIndexPosition[      6675,        219]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Visualizing Molecules", "Subtitle"],

Cell["\<\
This example makes use of data obtained from a third party website:
http://www.rcsb.org/pdb/cgi/explore.cgi?pid=22201112242025&page=0&pdbId=1A7F\
\

\>", "Text"],

Cell["First, we import the data as a table.", "Text"],

Cell[BoxData[
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(data = Import["\<1A7F.pdb\>", "\<Table\>"];\)\)], "Input"],

Cell["Each row of interest has the following form.", "Text"],

Cell[BoxData[
    \(data[\([102]\)]\)], "Input"],

Cell["\<\
The following extracts out only those rows containing atomic coordinates and \
types.\
\>", "Text"],

Cell[BoxData[
    \(\(mol = Take[data, {102, 15238}];\)\)], "Input"],

Cell["\<\
Next, we trim the data to get only the coordinates and types, discarding the \
other information.\
\>", "Text"],

Cell[BoxData[
    \(\(molcoords = 
        mol /. {a_, b_, c_, d_, e_, f_, x_, y_, z_, j_, k_, 
              type_} \[Rule] {x, y, z, type};\)\)], "Input"],

Cell["Here we can see the form of the remaining elements.", "Text"],

Cell[BoxData[
    \(molcoords[\([1]\)]\)], "Input"],

Cell["For convenience, we define a scale factor.", "Text"],

Cell[BoxData[
    \(\(scale =  .007;\)\)], "Input"],

Cell["\<\
Next, we define colors and radii for oxygen, nitrogen, carbon, and hydrogen, \
respectively.\
\>", "Text"],

Cell[BoxData[
    \(sc = Yellow; sr = 5\ scale;\)], "Input"],

Cell[BoxData[
    \(oc = Green; or = 4\ scale;\)], "Input"],

Cell[BoxData[
    \(nc = Brown; nr = 3\ scale;\)], "Input"],

Cell[BoxData[
    \(cc = Black; cr = 2\ scale;\)], "Input"],

Cell[BoxData[
    \(hc = Red; hr = 1\ scale;\)], "Input"],

Cell["\<\
Now we isolate the different elements and apply the appropriate colors and \
radii.\
\>", "Text"],

Cell[BoxData[
    \(\(n = {nc, 
          Flatten[Cases[
              molcoords, {x_, y_, z_, "\<N\>"} \[Rule] {PointSize[nr], 
                  Point[{x, y, z}]}, Infinity]]};\)\)], "Input"],

Cell[BoxData[
    \(\(o = {oc, 
          Flatten[Cases[
              molcoords, {x_, y_, z_, "\<O\>"} \[Rule] {PointSize[or], 
                  Point[{x, y, z}]}, Infinity]]};\)\)], "Input"],

Cell[BoxData[
    \(\(h = {hc, 
          Flatten[Cases[
              molcoords, {x_, y_, z_, "\<H\>"} \[Rule] {PointSize[hr], 
                  Point[{x, y, z}]}, Infinity]]};\)\)], "Input"],

Cell[BoxData[
    \(\(c = {cc, 
          Flatten[Cases[
              molcoords, {x_, y_, z_, "\<C\>"} \[Rule] {PointSize[cr], 
                  Point[{x, y, z}]}, Infinity]]};\)\)], "Input"],

Cell[BoxData[
    \(\(s = {sc, 
          Flatten[Cases[
              molcoords, {x_, y_, z_, "\<S\>"} \[Rule] {PointSize[sr], 
                  Point[{x, y, z}]}, Infinity]]};\)\)], "Input"],

Cell["This particular dataset contains over 15,000 atoms.", "Text"],

Cell[BoxData[
    \(\((Length[n[\([2]\)]] + Length[o[\([2]\)]] + Length[h[\([2]\)]] + 
          Length[c[\([2]\)]] + Length[s[\([2]\)]])\)/2\)], "Input"],

Cell["Finally, we can visualize the molecule.", "Text"],

Cell[BoxData[
    \(Show[
      Graphics3D[{n, o, h, c, s}, LightSources \[Rule] {{{1, 1, 1}, White}}, 
        ImageSize \[Rule] 600, Boxed \[Rule] False, 
        Background \[Rule] RGBColor[ .9,  .9,  .9], 
        SphericalRegion \[Rule] True]]\)], "Input"],

Cell["\<\
Here, we create an animation by rotating the camera around the molecule, just \
above the x-y plane.\
\>", "Text"],

Cell[BoxData[
    \(\(anim = 
        Table[Show[
            Graphics3D[{n, o, h, c, s}, 
              LightSources \[Rule] {{{1, 1, 1}, White}}, 
              ImageSize \[Rule] 600, Boxed \[Rule] False, 
              Background \[Rule] RGBColor[ .9,  .9,  .9], 
              ViewPoint \[Rule] {2\ Cos[t], 2\ Sin[t],  .5}, 
              SphericalRegion \[Rule] True]], {t, 0, 
            2\ \[Pi],  .1}];\)\)], "Input"],

Cell["Here's the first frame of the animation.", "Text"],

Cell["Now, we can export the animation.", "Text"],

Cell[BoxData[
    \(Export["\<C:\\Documents and Settings\\jeffb\\Desktop\\insulin.gif\>", 
      anim, "\<GIF\>", 
      ConversionOptions \[Rule] {"\<Loop\>" \[Rule] True}]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 935}},
WindowSize->{1108, 835},
WindowMargins->{{31, Automatic}, {Automatic, -3}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 41, 0, 51, "Subtitle"],
Cell[1820, 55, 170, 4, 71, "Text"],
Cell[1993, 61, 53, 0, 33, "Text"],
Cell[2049, 63, 183, 4, 30, "Input"],
Cell[2235, 69, 80, 1, 30, "Input"],
Cell[2318, 72, 60, 0, 33, "Text"],
Cell[2381, 74, 48, 1, 30, "Input"],
Cell[2432, 77, 109, 3, 33, "Text"],
Cell[2544, 82, 68, 1, 30, "Input"],
Cell[2615, 85, 121, 3, 33, "Text"],
Cell[2739, 90, 156, 3, 30, "Input"],
Cell[2898, 95, 67, 0, 33, "Text"],
Cell[2968, 97, 51, 1, 30, "Input"],
Cell[3022, 100, 58, 0, 33, "Text"],
Cell[3083, 102, 51, 1, 30, "Input"],
Cell[3137, 105, 116, 3, 33, "Text"],
Cell[3256, 110, 60, 1, 30, "Input"],
Cell[3319, 113, 59, 1, 30, "Input"],
Cell[3381, 116, 59, 1, 30, "Input"],
Cell[3443, 119, 59, 1, 30, "Input"],
Cell[3505, 122, 57, 1, 30, "Input"],
Cell[3565, 125, 107, 3, 33, "Text"],
Cell[3675, 130, 193, 4, 30, "Input"],
Cell[3871, 136, 193, 4, 30, "Input"],
Cell[4067, 142, 193, 4, 30, "Input"],
Cell[4263, 148, 193, 4, 30, "Input"],
Cell[4459, 154, 193, 4, 30, "Input"],
Cell[4655, 160, 67, 0, 33, "Text"],
Cell[4725, 162, 154, 2, 30, "Input"],
Cell[4882, 166, 55, 0, 33, "Text"],
Cell[4940, 168, 261, 5, 50, "Input"],
Cell[5204, 175, 124, 3, 33, "Text"],
Cell[5331, 180, 426, 9, 70, "Input"],
Cell[5760, 191, 56, 0, 33, "Text"],
Cell[5819, 193, 49, 0, 33, "Text"],
Cell[5871, 195, 186, 3, 30, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

